@@ -1,3 +1,4 @@
+import os
 import logging
 import pickle
 from datetime import datetime
@@ -82,7 +83,10 @@ class UpliftRandomForest:
         if self.save:
             self.log.debug("Saving ...")
             date_str = datetime.now().strftime("%d_%m_%Y_%H_%M_%S")
-            filename = self.path + 'results/models/{}_Direct_Uplift_{}.pickle'.format(str(self.split_number), date_str)
+            path = self.path + 'results/models/'
+            filename = path + f'{self.split_number}_URF_{self.parameters["evaluationFunction"]}_{date_str}.pickle'
+            if not os.path.exists(path):
+                os.makedirs(path)
             pickle.dump(urf, open(filename, 'wb'))
 
         self.log.debug("Predicting ... ")
